@@ -1,5 +1,7 @@
 import sys
 
+from inspect import isasyncgenfunction
+
 import param
 
 from param.parameterized import iscoroutinefunction
@@ -183,7 +185,7 @@ def _param_bind(function, *args, watch=False, **kwargs):
         elif isinstance(v, param.Parameter):
             dependencies[kw] = v
 
-    def combine_arguments(wargs, wkwargs):
+    def combine_arguments(wargs, wkwargs, asynchronous=False):
         combined_args = []
         for arg in args:
             if hasattr(arg, '_dinfo'):
@@ -200,7 +202,13 @@ def _param_bind(function, *args, watch=False, **kwargs):
                 arg = getattr(arg.owner, arg.name)
             combined_kwargs[kw] = arg
         for kw, arg in wkwargs.items():
-            if kw.startswith('__arg') or kw.startswith('__kwarg') or kw.startswith('__fn'):
+            if asynchronous:
+                if kw.startswith('__arg'):
+                    combined_args[int(kw[5:])] = arg
+                elif kw.startswith('__kwarg'):
+                    combined_kwargs[kw[8:]] = arg
+                continue
+            elif kw.startswith('__arg') or kw.startswith('__kwarg') or kw.startswith('__fn'):
                 continue
             combined_kwargs[kw] = arg
         return combined_args, combined_kwargs
@@ -216,12 +224,24 @@ def _param_bind(function, *args, watch=False, **kwargs):
                 fn = eval_function(p)
         return fn
 
-    if iscoroutinefunction(function):
+    if isasyncgenfunction(function):
+        async def wrapped(*wargs, **wkwargs):
+            combined_args, combined_kwargs = combine_arguments(
+                wargs, wkwargs, asynchronous=True
+            )
+            evaled = eval_fn()(*combined_args, **combined_kwargs)
+            async for val in evaled:
+                yield val
+        wrapper_fn = depends(**dependencies, watch=watch)(wrapped)
+        wrapped._dinfo = wrapper_fn._dinfo
+    elif iscoroutinefunction(function):
         @depends(**dependencies, watch=watch)
         async def wrapped(*wargs, **wkwargs):
-            combined_args, combined_kwargs = combine_arguments(wargs, wkwargs)
-
-            return await eval_fn()(*combined_args, **combined_kwargs)
+            combined_args, combined_kwargs = combine_arguments(
+                wargs, wkwargs, asynchronous=True
+            )
+            evaled = eval_fn()(*combined_args, **combined_kwargs)
+            return await evaled
     else:
         @depends(**dependencies, watch=watch)
         def wrapped(*wargs, **wkwargs):
