@@ -14,6 +14,6 @@ from .reactive_html import ReactiveHTML  # noqa
 from .state import State  # noqa
 from .trend import TrendIndicator  # noqa
 from .widgets import (  # noqa
-    Audio, CustomSelect, FileDownload, Player, Progress, SingleSelect, Video,
-    VideoStream,
+    Audio, CustomSelect, FileDownload, Player, Progress, SingleSelect,
+    TooltipIcon, Video, VideoStream,
 )
