@@ -1,10 +1,10 @@
 import {undisplay} from "@bokehjs/core/dom"
 import {isArray} from "@bokehjs/core/util/types"
-import {build_views} from "@bokehjs/core/build_views"
 import {ModelEvent} from "@bokehjs/core/bokeh_events"
 import {div} from "@bokehjs/core/dom"
 import {Enum} from "@bokehjs/core/kinds"
 import * as p from "@bokehjs/core/properties";
+import {LayoutDOM} from "@bokehjs/models/layouts/layout_dom"
 import {ColumnDataSource} from "@bokehjs/models/sources/column_data_source"
 import {TableColumn} from "@bokehjs/models/widgets/tables"
 import {Attrs} from "@bokehjs/core/types"
@@ -426,7 +426,6 @@ export class DataTabulatorView extends HTMLBoxView {
 
     let configuration = this.getConfiguration()
     this.tabulator = new Tabulator(el, configuration)
-    console.log(el, this.tabulator)
     this.watch_stylesheets()
     this.init_callbacks()
   }
@@ -466,7 +465,6 @@ export class DataTabulatorView extends HTMLBoxView {
     this.tabulator.on("scrollVertical", debounce(() => {
       this.setStyles()
     }, 50, false))
-    this.tabulator.on("rowFormatter", (row: any) => this._render_row(row))
 
     // Sync state with model
     this.tabulator.on("rowSelectionChanged", (data: any, rows: any) => this.rowSelectionChanged(data, rows))
@@ -577,6 +575,7 @@ export class DataTabulatorView extends HTMLBoxView {
       paginationSize: this.model.page_size,
       paginationInitialPage: 1,
       groupBy: this.groupBy,
+      rowFormatter: (row: any) => this._render_row(row),
       frozenRows: (row: any) => {
 	return this.model.frozen_rows.length ? this.model.frozen_rows.includes(row._row.data._index) : false
       }
@@ -599,24 +598,31 @@ export class DataTabulatorView extends HTMLBoxView {
     }
   }
 
+  get child_models(): LayoutDOM[] {
+    const children = []
+    for (const idx of this.model.expanded) {
+      if (this.model.children.has(idx))
+        children.push(this.model.children.get(idx))
+    }
+    return children
+  }
+
   renderChildren(): void {
     new Promise(async (resolve: any) => {
-      const children = []
-      for (const idx of this.model.expanded) {
-        if (this.model.children.has(idx))
-          children.push(this.model.children.get(idx))
-      }
-      await build_views(this._child_views, children, {parent: (null as any)})
+      await this.build_child_views()
       resolve(null)
     }).then(() => {
       for (const r of this.model.expanded) {
         const row = this.tabulator.getRow(r)
-        this._render_row(row)
+        this._render_row(row, false)
       }
+      this._update_children()
+      this.tabulator.rowManager.adjustTableSize()
+      this.invalidate_layout()
     })
   }
 
-  _render_row(row: any): void {
+  _render_row(row: any, resize: boolean = true): void {
     const index = row._row?.data._index
     if (!this.model.expanded.includes(index) || !this.model.children.has(index))
       return
@@ -624,23 +630,20 @@ export class DataTabulatorView extends HTMLBoxView {
     const view = this._child_views.get(model)
     if (view == null)
       return
-    (view as any)._parent = this
     const rowEl = row.getElement()
-    let viewEl = rowEl.children[rowEl.children.length-1]
-    if (viewEl.className === 'bk') {
-      if (viewEl.children.length)
-        return
-    } else {
-      viewEl = null
-    }
-    if (viewEl == null) {
-      const style = getComputedStyle(this.tabulator.element.children[1].children[0])
-      const bg = style.backgroundColor
-      const neg_margin = "-" + rowEl.style.paddingLeft
-      viewEl = div({style: "background-color: " + bg +"; margin-left:" + neg_margin})
-    }
+    const style = getComputedStyle(this.tabulator.element.children[1].children[0])
+    const bg = style.backgroundColor
+    const neg_margin = rowEl.style.paddingLeft ? "-" + rowEl.style.paddingLeft : '0';
+    const viewEl = div({style: "background-color: " + bg +"; margin-left:" + neg_margin + "; max-width: 100%; overflow-x: hidden;"})
+    viewEl.appendChild(view.el)
     rowEl.appendChild(viewEl)
-    view.render_to(viewEl)
+    view.render()
+    view.after_render()
+    if (resize) {
+      this._update_children()
+      this.tabulator.rowManager.adjustTableSize()
+      this.invalidate_layout()
+    }
   }
 
   _expand_render(cell: any): string {
@@ -978,7 +981,6 @@ export class DataTabulatorView extends HTMLBoxView {
   }
 
   setPage(): void {
-    console.log(Math.min(this.model.max_page, this.model.page))
     this.tabulator.setPage(Math.min(this.model.max_page, this.model.page))
     if (this.model.pagination === "local") {
       this.renderChildren()
