@@ -1,24 +1,26 @@
-import { HTMLBox } from "@bokehjs/models/layouts/html_box"
 import * as p from "@bokehjs/core/properties"
 import { div } from "@bokehjs/core/dom"
-import {ModelEvent, JSON} from "@bokehjs/core/bokeh_events"
+import {ModelEvent} from "@bokehjs/core/bokeh_events"
+import {Attrs} from "@bokehjs/core/types"
 
-import { PanelHTMLBoxView, set_size } from "./layout"
+import {HTMLBox, HTMLBoxView, set_size} from "./layout"
 
 
 export class KeystrokeEvent extends ModelEvent {
-  event_name: string = "keystroke"
-
   constructor(readonly key: string) {
     super()
   }
 
-  protected _to_json(): JSON {
+  protected get event_values(): Attrs {
     return {model: this.origin, key: this.key}
   }
+
+  static {
+    this.prototype.event_name = "keystroke"
+  }
 }
 
-export class TerminalView extends PanelHTMLBoxView {
+export class TerminalView extends HTMLBoxView {
   model: Terminal
   term: any // Element
   webLinksAddon: any
@@ -53,7 +55,7 @@ export class TerminalView extends PanelHTMLBoxView {
 
     this.write()
 
-    this.el.appendChild(this.container)
+    this.shadow_el.appendChild(this.container)
   }
 
   getNewTerminal(): any {
@@ -88,11 +90,8 @@ export class TerminalView extends PanelHTMLBoxView {
   }
 
   fit(): void {
-    const sizing = this.box_sizing()
-    const vert_margin = sizing.margin == null ? 0 : sizing.margin.top + sizing.margin.bottom
-    const horz_margin = sizing.margin == null ? 0 : sizing.margin.left + sizing.margin.right
-    const width = (this.layout.inner_bbox.width || this.model.width || 0) - horz_margin
-    const height = (this.layout.inner_bbox.height || this.model.height || 0) - vert_margin
+    const width = this.container.offsetWidth;
+    const height = this.container.offsetHeight;
     const renderer = this.term._core._renderService
     const cell_width = renderer.dimensions.actualCellWidth || 9
     const cell_height = renderer.dimensions.actualCellHeight || 18
@@ -111,11 +110,6 @@ export class TerminalView extends PanelHTMLBoxView {
     super.after_layout()
     this.fit()
   }
-
-  resize_layout(): void {
-    super.resize_layout()
-    this.fit()
-  }
 }
 
 export namespace Terminal {
@@ -141,15 +135,15 @@ export class Terminal extends HTMLBox {
 
   static __module__ = "panel.models.terminal"
 
-  static init_Terminal(): void {
+  static {
     this.prototype.default_view = TerminalView;
 
     this.define<Terminal.Props>(({Any, Int, String}) => ({
       _clears:        [ Int,     0 ],
       options:        [ Any,    {} ],
-      output:         [ String,    ],
-      ncols:          [ Int        ],
-      nrows:          [ Int        ],
+      output:         [ String, '' ],
+      ncols:          [ Int,     0 ],
+      nrows:          [ Int,     0 ],
     }))
   }
 }
