@@ -1,33 +1,45 @@
+import {div} from "@bokehjs/core/dom"
 import * as p from "@bokehjs/core/properties"
-import {ModelEvent, JSON} from "@bokehjs/core/bokeh_events"
+import {ModelEvent} from "@bokehjs/core/bokeh_events"
 import {isArray} from "@bokehjs/core/util/types"
-import {HTMLBox, HTMLBoxView} from "@bokehjs/models/layouts/html_box"
+import {LayoutDOM, LayoutDOMView} from "@bokehjs/models/layouts/layout_dom"
+import {Attrs} from "@bokehjs/core/types"
+
+import {set_size} from "./layout"
 
 import {debounce} from  "debounce"
 
-export class VegaEvent extends ModelEvent {
-  event_name: string = "vega_event"
 
+export class VegaEvent extends ModelEvent {
   constructor(readonly data: any) {
     super()
   }
 
-  protected _to_json(): JSON {
+  protected get event_values(): Attrs {
     return {model: this.origin, data: this.data}
   }
+
+  static {
+    this.prototype.event_name = "vega_event"
+  }
 }
 
-export class VegaPlotView extends HTMLBoxView {
+export class VegaPlotView extends LayoutDOMView {
   model: VegaPlot
   vega_view: any
+  container: HTMLDivElement
   _callbacks: string[]
   _connected: string[]
+  _replot: any
+  _resize: any
+  _rendered: boolean = false
 
   connect_signals(): void {
     super.connect_signals()
     const {data, show_actions, theme} = this.model.properties
+    this._replot = debounce(() => this._plot(), 20)
     this.on_change([data, show_actions, theme], () => {
-      this._plot()
+      this._replot()
     })
     this.connect(this.model.properties.data_sources.change, () => this._connect_sources())
     this.connect(this.model.properties.events.change, () => {
@@ -48,17 +60,34 @@ export class VegaPlotView extends HTMLBoxView {
     for (const ds in this.model.data_sources) {
       const cds = this.model.data_sources[ds]
       if (this._connected.indexOf(ds) < 0) {
-        this.connect(cds.properties.data.change, this._plot)
+        this.connect(cds.properties.data.change, () => this._replot())
         this._connected.push(ds)
       }
     }
   }
 
+  override remove(): void {
+    if (this.vega_view) {
+      this.vega_view.finalize()
+    }
+    super.remove()
+  }
+
   _dispatch_event(name: string, value: any): void {
     if ('vlPoint' in value && value.vlPoint.or != null) {
       const indexes = []
-      for (const index of value.vlPoint.or)
-        indexes.push(index._vgsid_)
+      for (const index of value.vlPoint.or) {
+        if (index._vgsid_ !== undefined) {  // If "_vgsid_" property exists
+          indexes.push(index._vgsid_);
+        } else {  // If "_vgsid_" property doesn't exist
+          // Iterate through all properties in the "index" object
+          for (const key in index) {
+            if (index.hasOwnProperty(key)) {  // To ensure key comes from "index" object itself, not its prototype
+              indexes.push({[key]: index[key]});  // Push a new object with this key-value pair into the array
+            }
+          }
+        }
+      }
       value = indexes
     }
     this.model.trigger_event(new VegaEvent({type: name, value: value}))
@@ -82,10 +111,18 @@ export class VegaPlotView extends HTMLBoxView {
     return datasets
   }
 
+  get child_models(): LayoutDOM[] {
+    return []
+  }
+
   render(): void {
     super.render()
+    this._rendered = false
+    this.container = div()
+    set_size(this.container, this.model)
     this._callbacks = []
     this._plot()
+    this.shadow_el.append(this.container)
   }
 
   _plot(): void {
@@ -110,12 +147,10 @@ export class VegaPlotView extends HTMLBoxView {
       this.model.data['datasets'] = datasets
     }
     const config: any = {actions: this.model.show_actions, theme: this.model.theme};
-    (window as any).vegaEmbed(this.el, this.model.data, config).then((result: any) => {
+
+    (window as any).vegaEmbed(this.container, this.model.data, config).then((result: any) => {
       this.vega_view = result.view
-      this.relayout()
-      if (this.vega_view._viewHeight <= 0 || this.vega_view._viewWidth <= 0) {
-        (window as any).dispatchEvent(new Event('resize'));
-      }
+      this._resize = debounce(() => this.resize_view(result.view), 50)
       const callback = (name: string, value: any) => this._dispatch_event(name, value)
       for (const event of this.model.events) {
         this._callbacks.push(event)
@@ -125,30 +160,28 @@ export class VegaPlotView extends HTMLBoxView {
     })
   }
 
-  relayout(): void {
-    this.update_layout()
-    this.compute_layout()
-    if (this.root !== this)
-      this.invalidate_layout()
-    else if ((this as any)._parent != undefined) // HACK: Support ReactiveHTML
-      (this as any)._parent.invalidate_layout()
+  after_layout(): void {
+    super.after_layout()
+    if (this.vega_view != null) {
+      this._resize()
+    }
   }
 
-  box_sizing(): any {
-    const sizing = super.box_sizing()
-    if (this.vega_view != null) {
-      if (sizing.height_policy === "fixed")
-        sizing.height = this.vega_view._viewHeight
-      if (sizing.width_policy === "fixed")
-        sizing.width = this.vega_view._viewWidth
+  resize_view(view: any): void {
+    const canvas = view._renderer.canvas()
+    if (!this._rendered && canvas !== null) {
+      for (const listener of view._eventListeners) {
+	if (listener.type === 'resize')
+	  listener.handler(new Event('resize'))
+      }
+      this._rendered = true
     }
-    return sizing
   }
 }
 
 export namespace VegaPlot {
   export type Attrs = p.AttrsOf<Props>
-  export type Props = HTMLBox.Props & {
+  export type Props = LayoutDOM.Props & {
     data: p.Property<any>
     data_sources: p.Property<any>
     events: p.Property<string[]>
@@ -160,7 +193,7 @@ export namespace VegaPlot {
 
 export interface VegaPlot extends VegaPlot.Attrs {}
 
-export class VegaPlot extends HTMLBox {
+export class VegaPlot extends LayoutDOM {
   properties: VegaPlot.Props
 
   constructor(attrs?: Partial<VegaPlot.Attrs>) {
@@ -169,16 +202,16 @@ export class VegaPlot extends HTMLBox {
 
   static __module__ = "panel.models.vega"
 
-  static init_VegaPlot(): void {
+  static {
     this.prototype.default_view = VegaPlotView
 
-    this.define<VegaPlot.Props>(({Any, Array, Boolean, String}) => ({
-      data:         [ Any,           {} ],
-      data_sources: [ Any,           {} ],
-      events:       [ Array(String), [] ],
-      show_actions: [ Boolean,    false ],
-      theme:        [ String,           ],
-      throttle:     [ Any,           {} ]
+    this.define<VegaPlot.Props>(({Any, Array, Boolean, Nullable, String}) => ({
+      data:         [ Any,                {} ],
+      data_sources: [ Any,                {} ],
+      events:       [ Array(String),      [] ],
+      show_actions: [ Boolean,         false ],
+      theme:        [ Nullable(String), null ],
+      throttle:     [ Any,                {} ]
     }))
   }
 }
