@@ -9,7 +9,7 @@ import sys
 
 from collections import defaultdict
 from typing import (
-    TYPE_CHECKING, Any, ClassVar, Mapping, Optional,
+    TYPE_CHECKING, Any, ClassVar, Dict, Mapping, Optional,
 )
 
 import numpy as np
@@ -19,8 +19,7 @@ from bokeh.models import ColumnDataSource
 from pyviz_comms import JupyterComm
 
 from ..util import is_dataframe, lazy_load
-from ..viewable import Layoutable
-from .base import PaneBase
+from .base import ModelPane
 
 if TYPE_CHECKING:
     from bokeh.document import Document
@@ -81,7 +80,7 @@ def recurse_data(data):
     return data
 
 
-class DeckGL(PaneBase):
+class DeckGL(ModelPane):
     """
     The `DeckGL` pane renders the Deck.gl
     JSON specification as well as PyDeck plots inside a panel.
@@ -143,38 +142,6 @@ class DeckGL(PaneBase):
             return isinstance(obj, pydeck.bindings.deck.Deck)
         return False
 
-    def _get_properties(self, layout: bool = True):
-        if self.object is None:
-            data, mapbox_api_key, tooltip = {}, self.mapbox_api_key, self.tooltips
-        elif isinstance(self.object, (str, dict)):
-            if isinstance(self.object, str):
-                data = json.loads(self.object)
-            else:
-                data = dict(self.object)
-                data['layers'] = [dict(layer) for layer in data.get('layers', [])]
-            mapbox_api_key = self.mapbox_api_key
-            tooltip = self.tooltips
-        else:
-            data = dict(self.object.__dict__)
-            mapbox_api_key = data.pop('mapbox_key', self.mapbox_api_key)
-            deck_widget = data.pop('deck_widget', None)
-            tooltip = self.tooltips if isinstance(self.tooltips, dict) else deck_widget.tooltip
-            data = {k: v for k, v in recurse_data(data).items() if v is not None}
-
-        # Delete undefined width and height
-        for view in data.get('views', []):
-            if view.get('width', False) is None:
-                view.pop('width')
-            if view.get('height', False) is None:
-                view.pop('height')
-
-        if layout:
-            properties = {p: getattr(self, p) for p in Layoutable.param
-                          if getattr(self, p) is not None}
-        else:
-            properties = {}
-        return data, dict(properties, tooltip=tooltip, mapbox_api_key=mapbox_api_key or "")
-
     @classmethod
     def _process_data(cls, data):
         columns = defaultdict(list)
@@ -229,14 +196,45 @@ class DeckGL(PaneBase):
                 sources.append(cds)
             layer['data'] = sources.index(cds)
 
+    def _transform_object(self, obj) -> Dict[str, Any]:
+        if self.object is None:
+            data, mapbox_api_key, tooltip = {}, self.mapbox_api_key, self.tooltips
+        elif isinstance(self.object, (str, dict)):
+            if isinstance(self.object, str):
+                data = json.loads(self.object)
+            else:
+                data = dict(self.object)
+                data['layers'] = [dict(layer) for layer in data.get('layers', [])]
+            mapbox_api_key = self.mapbox_api_key
+            tooltip = self.tooltips
+        else:
+            data = dict(self.object.__dict__)
+            mapbox_api_key = data.pop('mapbox_key', self.mapbox_api_key)
+            deck_widget = data.pop('deck_widget', None)
+            if isinstance(self.tooltips, dict) or deck_widget is None:
+                tooltip = self.tooltips
+            else:
+                tooltip = deck_widget.tooltip
+            data = {k: v for k, v in recurse_data(data).items() if v is not None}
+
+        # Delete undefined width and height
+        for view in data.get('views', []):
+            if view.get('width', False) is None:
+                view.pop('width')
+            if view.get('height', False) is None:
+                view.pop('height')
+
+        return dict(data=data, tooltip=tooltip, mapbox_api_key=mapbox_api_key or "")
+
     def _get_model(
         self, doc: Document, root: Optional[Model] = None,
         parent: Optional[Model] = None, comm: Optional[Comm] = None
     ) -> Model:
-        DeckGLPlot = lazy_load(
+        self._bokeh_model = DeckGLPlot = lazy_load(
             'panel.models.deckgl', 'DeckGLPlot', isinstance(comm, JupyterComm), root
         )
-        data, properties = self._get_properties()
+        properties = self._get_properties(doc)
+        data = properties.pop('data')
         properties['data_sources'] = sources = []
         self._update_sources(data, sources)
         properties['layers'] = data.pop('layers', [])
@@ -248,7 +246,8 @@ class DeckGL(PaneBase):
         return model
 
     def _update(self, ref: str, model: Model) -> None:
-        data, properties = self._get_properties(layout=False)
+        properties = self._get_properties(model.document)
+        data = properties.pop('data')
         self._update_sources(data, model.data_sources)
         properties['data'] = data
         properties['layers'] = data.pop('layers', [])
