@@ -128,18 +128,26 @@ def test_plotly_3d_plot(page, port, plotly_3d_plot):
 
 
 @plotly_available
+@pytest.mark.flaky(max_runs=3)
 def test_plotly_hover_data(page, port, plotly_2d_plot):
     serve(plotly_2d_plot, port=port, threaded=True, show=False)
+
+    hover_data = []
+    plotly_2d_plot.param.watch(lambda e: hover_data.append(e.new), 'hover_data')
+
     time.sleep(0.2)
     page.goto(f"http://localhost:{port}")
 
+    plotly_plot = page.locator('.js-plotly-plot .plot-container.plotly')
+    expect(plotly_plot).to_have_count(1)
+
     # Select and hover on first point
-    point = page.locator(':nth-match(.js-plotly-plot .plot-container.plotly path.point, 1)')
+    point = plotly_plot.locator('g.points path.point').nth(0)
     point.hover(force=True)
 
     time.sleep(0.2)
 
-    assert plotly_2d_plot.hover_data == {
+    assert {
         'points': [{
             'curveNumber': 0,
             'pointIndex': 0,
@@ -147,7 +155,7 @@ def test_plotly_hover_data(page, port, plotly_2d_plot):
             'x': 0,
             'y': 2
         }]
-    }
+    } in hover_data
 
     # Hover somewhere else
     plot = page.locator('.js-plotly-plot .plot-container.plotly g.scatterlayer')
@@ -159,13 +167,19 @@ def test_plotly_hover_data(page, port, plotly_2d_plot):
 
 
 @plotly_available
+@pytest.mark.flaky(max_runs=3)
 def test_plotly_click_data(page, port, plotly_2d_plot):
     serve(plotly_2d_plot, port=port, threaded=True, show=False)
+
     time.sleep(0.2)
+
     page.goto(f"http://localhost:{port}")
 
+    plotly_plot = page.locator('.js-plotly-plot .plot-container.plotly')
+    expect(plotly_plot).to_have_count(1)
+
     # Select and click on first point
-    point = page.locator(':nth-match(.js-plotly-plot .plot-container.plotly path.point, 1)')
+    point = page.locator('.js-plotly-plot .plot-container.plotly path.point').nth(0)
     point.click(force=True)
 
     time.sleep(0.2)
@@ -179,3 +193,42 @@ def test_plotly_click_data(page, port, plotly_2d_plot):
             'y': 2
         }]
     }
+
+
+
+@plotly_available
+@pytest.mark.flaky(max_runs=3)
+def test_plotly_select_data(page, port, plotly_2d_plot):
+    serve(plotly_2d_plot, port=port, threaded=True, show=False)
+
+    time.sleep(0.5)
+
+    page.goto(f"http://localhost:{port}")
+
+    plotly_plot = page.locator('.js-plotly-plot .plot-container.plotly')
+    expect(plotly_plot).to_have_count(1)
+
+    page.locator('a.modebar-btn[data-val="select"]').click()
+
+    bbox = page.locator('.js-plotly-plot .plot-container.plotly').bounding_box()
+
+    page.mouse.move(bbox['x']+100, bbox['y']+100)
+    page.mouse.down()
+    page.mouse.move(bbox['x']+bbox['width'], bbox['y']+bbox['height'], steps=5)
+    page.mouse.up()
+
+    time.sleep(0.2)
+
+    selected = plotly_2d_plot.selected_data
+    assert selected is not None
+    assert 'points' in selected
+    assert selected['points'] == [{
+        'curveNumber': 0,
+        'pointIndex': 1,
+        'pointNumber': 1,
+        'x': 1,
+        'y': 3
+    }]
+    assert 'range' in selected
+    assert 'x' in selected['range']
+    assert 'y' in selected['range']
