@@ -3,7 +3,11 @@ import time
 import param
 import pytest
 
-pytestmark = pytest.mark.ui
+try:
+    from playwright.sync_api import expect
+    pytestmark = pytest.mark.ui
+except ImportError:
+    pytestmark = pytest.mark.skip('playwright not available')
 
 from panel.io.server import serve
 from panel.reactive import ReactiveHTML
@@ -32,11 +36,11 @@ def test_reactive_html_click_js_event(page, port):
 
     page.goto(f"http://localhost:{port}")
 
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
 
     page.locator(".reactive").click()
 
-    assert page.text_content(".reactive") == '2'
+    expect(page.locator(".reactive")).to_have_text('2')
 
     time.sleep(0.2)
 
@@ -51,13 +55,13 @@ def test_reactive_html_set_loading_no_rerender(page, port):
 
     page.goto(f"http://localhost:{port}")
 
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
     component.loading = True
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
     component.loading = False
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
 
 def test_reactive_html_changing_css_classes_rerenders(page, port):
     component = ReactiveComponent()
@@ -68,16 +72,19 @@ def test_reactive_html_changing_css_classes_rerenders(page, port):
 
     page.goto(f"http://localhost:{port}")
 
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
+
     component.css_classes = ['custom']
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
+
     component.loading = True
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
+
     component.css_classes = []
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
 
 def test_reactive_html_set_background_no_rerender(page, port):
     component = ReactiveComponent()
@@ -88,10 +95,12 @@ def test_reactive_html_set_background_no_rerender(page, port):
 
     page.goto(f"http://localhost:{port}")
 
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
+
     component.styles = dict(background='red')
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
+
     component.styles = dict(background='green')
     time.sleep(0.1)
-    assert page.text_content(".reactive") == '1'
+    expect(page.locator(".reactive")).to_have_text('1')
