@@ -1,13 +1,28 @@
+import contextlib
+import os
+import platform
+import re
+import subprocess
 import sys
 import time
+import warnings
+
+from queue import Empty, Queue
+from threading import Thread
 
 import numpy as np
 import pytest
 
 from packaging.version import Version
 
+import panel as pn
+
 from panel.io.server import serve
 
+# Ignore tests which are not yet working with Bokeh 3.
+# Will begin to fail again when the first rc is released.
+pnv = Version(pn.__version__)
+
 try:
     import holoviews as hv
     hv_version = Version(hv.__version__)
@@ -23,12 +38,6 @@ except Exception:
     mpl = None
 mpl_available = pytest.mark.skipif(mpl is None, reason="requires matplotlib")
 
-try:
-    import pandas as pd
-except Exception:
-    pd = None
-pd_available = pytest.mark.skipif(pd is None, reason="requires pandas")
-
 try:
     import streamz
 except Exception:
@@ -41,7 +50,14 @@ except Exception:
     jupyter_bokeh = None
 jb_available = pytest.mark.skipif(jupyter_bokeh is None, reason="requires jupyter_bokeh")
 
+APP_PATTERN = re.compile(r'Bokeh app running at: http://localhost:(\d+)/')
+ON_POSIX = 'posix' in sys.builtin_module_names
+
+unix_only = pytest.mark.skipif(platform.system() != 'Linux', reason="Only supported on Linux")
+
+from panel.pane.alert import Alert
 from panel.pane.markup import Markdown
+from panel.widgets.button import _ButtonBase
 
 
 def mpl_figure():
@@ -54,12 +70,23 @@ def mpl_figure():
 
 
 def check_layoutable_properties(layoutable, model):
-    layoutable.background = '#ffffff'
-    assert model.background == '#ffffff'
+    layoutable.styles = {"background": '#fffff0'}
+    assert model.styles["background"] == '#fffff0'
+
+    # Is deprecated, but we still support it for now.
+    with warnings.catch_warnings():
+        warnings.simplefilter("ignore")
+        layoutable.background = '#ffffff'
+    assert model.styles["background"] == '#ffffff'
 
     layoutable.css_classes = ['custom_class']
-    if isinstance(layoutable, Markdown):
-        assert model.css_classes == ['custom_class', 'markdown']
+    if isinstance(layoutable, Alert):
+        print(model.css_classes)
+        assert model.css_classes == ['markdown', 'custom_class', 'alert', 'alert-primary']
+    elif isinstance(layoutable, Markdown):
+        assert model.css_classes == ['markdown', 'custom_class']
+    elif isinstance(layoutable, _ButtonBase):
+        assert model.css_classes == ['solid', 'custom_class']
     else:
         assert model.css_classes == ['custom_class']
 
@@ -82,7 +109,7 @@ def check_layoutable_properties(layoutable, model):
     assert model.max_width == 550
 
     layoutable.margin = 10
-    assert model.margin == (10, 10, 10, 10)
+    assert model.margin == 10
 
     layoutable.sizing_mode = 'stretch_width'
     assert model.sizing_mode == 'stretch_width'
@@ -175,7 +202,84 @@ def get_ctrl_modifier():
         raise ValueError(f'No control modifier defined for platform {sys.platform}')
 
 
-def serve_panel_widget(page, port, pn_widget, sleep=0.2):
+def serve_panel_widget(page, port, pn_widget, sleep=0.5):
     serve(pn_widget, port=port, threaded=True, show=False)
     time.sleep(sleep)
     page.goto(f"http://localhost:{port}")
+
+
+@contextlib.contextmanager
+def run_panel_serve(args, cwd=None):
+    cmd = [sys.executable, "-m", "panel", "serve"] + args
+    p = subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, shell=False, cwd=cwd, close_fds=ON_POSIX)
+    try:
+        yield p
+    except Exception as e:
+        p.terminate()
+        p.wait()
+        print("An error occurred: %s", e)
+        try:
+            out = p.stdout.read().decode()
+            print("\n---- subprocess stdout follows ----\n")
+            print(out)
+        except Exception:
+            pass
+        raise
+    else:
+        p.terminate()
+        p.wait()
+
+
+class NBSR:
+    def __init__(self, stream) -> None:
+        '''
+        NonBlockingStreamReader
+
+        stream: the stream to read from.
+                Usually a process' stdout or stderr.
+        '''
+
+        self._s = stream
+        self._q = Queue()
+
+        def _populateQueue(stream, queue):
+            '''
+            Collect lines from 'stream' and put them in 'queue'.
+            '''
+            for line in iter(stream.readline, b''):
+                queue.put(line)
+            stream.close()
+
+        self._t = Thread(target = _populateQueue,
+                args = (self._s, self._q))
+        self._t.daemon = True
+        self._t.start() #start collecting lines from the stream
+
+    def readline(self, timeout=None):
+        try:
+            return self._q.get(
+                block=timeout is not None,
+                timeout=timeout
+            )
+        except Empty:
+            return None
+
+def wait_for_port(stdout):
+    nbsr = NBSR(stdout)
+    m = None
+    for i in range(20):
+        o = nbsr.readline(0.5)
+        if not o:
+            continue
+        m = APP_PATTERN.search(o.decode('utf-8'))
+        if m is not None:
+            break
+    if m is None:
+        pytest.fail("no matching log line in process output")
+    return int(m.group(1))
+
+def write_file(content, file_obj):
+    file_obj.write(content)
+    file_obj.flush()
+    os.fsync(file_obj)
+    file_obj.seek(0)
